@@ -43,6 +43,7 @@ OC.L10N.register(
     "Accounts" : "Уліковыя запісы",
     "General" : "Агульныя",
     "Layout" : "Макет",
+    "List" : "Спіс",
     "Sorting" : "Сартаванне",
     "Privacy and security" : "Прыватнасць і бяспека",
     "S/MIME" : "S/MIME",
@@ -70,6 +71,7 @@ OC.L10N.register(
     "Discard & close draft" : "Адхіліць і закрыць чарнавік",
     "Enable formatting" : "Уключыць фарматаванне",
     "Disable formatting" : "Выключыць фарматаванне",
+    "Smart picker" : "Smart picker",
     "Tomorrow morning" : "Заўтра ранкам",
     "Tomorrow afternoon" : "Заўтра ў другой палове дня",
     "Enter a date" : "Увядзіце дату",
@@ -98,6 +100,7 @@ OC.L10N.register(
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Пераслаць {number} як далучэнне","Пераслаць {number} як далучэнне","Пераслаць {number} як далучэнне","Пераслаць {number} як далучэнне"],
     "Mark as unread" : "Пазначыць як непрачытанае",
     "Mark as read" : "Пазначыць як прачытанае",
+    "All day" : "Увесь дзень",
     "Attendees" : "Удзельнікі",
     "Description" : "Апісанне",
     "Create" : "Стварыць",
