@@ -14,8 +14,18 @@ OC.L10N.register(
     "Mail" : "Mail",
     "You are reaching your mailbox quota limit for {account_email}" : "Du er ved at nå din postkassekvote for {account_email}",
     "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Du bruger i øjeblikket {percentage} af din postkasseplads. Frigør plads ved at slette unødvendige e-mails.",
+    "Mail Application" : "Mail applikation",
     "Mails" : "Mails",
+    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following email: %3$s" : "Afsender e-mail: %1$s er ikke i adressebogen, men afsendernavnet: %2$s er i adressebogen med den følgende e-mail: %3$s",
+    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following emails: %3$s" : "Afsender e-mail: %1$s er ikke i adressebogen, men afsendernavnet: %2$s er i adressebogen med de følgende e-mails: %3$s",
+    "Sender is using a custom email: %1$s instead of the sender email: %2$s" : "Afsender anvender en brugerdefineret e-mail: %1$s i stedet for afsender e-mailen: %2$s",
     "Sent date is in the future" : "Afsendelsesdatoen ligger i fremtiden",
+    "Some addresses in this message are not matching the link text" : "Nogle adresser i denne besked matcher ikke link teksten",
+    "Reply-To email: %1$s  is different from the sender email: %2$s" : "Svar-til e-mail: %1$s  er forskellig fra afsender e-mailen: %2$s",
+    "Mail connection performance" : "Mailforbindelsesydelse",
+    "Slow mail service detected (%1$s) an attempt to connect to several accounts took an average of %2$s seconds per account" : "Langsom mailservice detekteret (%1$s) et forsøg på at forbinde til flere konti tog i gennemsnit %2$s sekunder per konto",
+    "Slow mail service detected (%1$s) an attempt to perform a mail box list operation on several accounts took an average of %2$s seconds per account" : "Langsom mailservice detekteret (%1$s) et forsøg på at udføre mailboks listehandling på flere konti tog i gennemsnit %2$s sekunder per konto",
+    "Mail Transport configuration" : "Mail transport konfiguration",
     "💌 A mail app for Nextcloud" : "💌 En mail app til Nextcloud",
     "Your session has expired. The page will be reloaded." : "Din session er udløbet. Siden vil blive genindlæst.",
     "Drafts are saved in:" : "Kladder gemmes i:",
@@ -28,6 +38,7 @@ OC.L10N.register(
     "Reconnect Google account" : "Gentilslut Google-kontoen",
     "Sign in with Google" : "Log ind med Google",
     "Reconnect Microsoft account" : "Gentilslut Microsoft-konto",
+    "Sign in with Microsoft" : "Log på med Microsoft",
     "Save" : "Gem",
     "Connect" : "Tilslut",
     "Looking up configuration" : "Søger konfiguration",
@@ -37,8 +48,10 @@ OC.L10N.register(
     "Testing authentication" : "Test af autentificering",
     "Awaiting user consent" : "Afventer brugerens samtykke",
     "Account created. Please follow the pop-up instructions to link your Google account" : "Konto oprettet. Følg venligst pop-up-instruktionerne for at linke din Google-konto.",
+    "Account created. Please follow the pop-up instructions to link your Microsoft account" : "Konto oprettet. Følg venligst instruktionerne i popup'en for at tilknytte din Microsoft konto",
     "Loading account" : "Indlæser konto",
     "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Konto opdateret. Følg venligst pop-up-instruktionerne for at genoprette forbindelsen til din Google-konto.",
+    "Account updated. Please follow the pop-up instructions to reconnect your Microsoft account" : "Konto opdateret. Følg venligst instruktionerne i popup'en for at genforbinde din Microsoft konto",
     "Account updated" : "Konto opdateret",
     "IMAP server is not reachable" : "IMAP server er ikke tilgængelig",
     "SMTP server is not reachable" : "SMTP server er ikke tilgængelig",
@@ -46,6 +59,7 @@ OC.L10N.register(
     "SMTP username or password is wrong" : "SMTP brugernavn eller kodeord er forkert",
     "IMAP connection failed" : "IMAP-forbindelse mislykkedes",
     "SMTP connection failed" : "SMTP-forbindelse mislykkedes",
+    "Authorization pop-up closed" : "Godkendelses popup lukket",
     "There was an error while setting up your account" : "Der opstod en fejl under opsætning af din konto",
     "Auto" : "Auto",
     "Name" : "Navn",
@@ -79,9 +93,15 @@ OC.L10N.register(
     "Default folders" : "Standardmapper",
     "Autoresponder" : "Autosvar",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automatisk svar på indgående beskeder. Hvis nogen sender dig flere beskeder, sendes dette automatiske svar højst en gang hver 4. dag.",
+    "Go to Sieve settings" : "Gå til Sieve indstillinger",
     "Filters" : "Filtre",
+    "Quick actions" : "Hurtige handlinger",
+    "Sieve script editor" : "Sieve script editor",
     "Mail server" : "Mail server",
+    "Sieve server" : "Sieve server",
+    "Folder search" : "Mappesøgning",
     "Update alias" : "Opdatér alias",
+    "Rename alias" : "Omdøb alias",
     "Show update alias form" : "Vis formular til opdateringsalias",
     "Delete alias" : "Slet alias",
     "Go back" : "Gå tilbage",
@@ -90,20 +110,48 @@ OC.L10N.register(
     "Add alias" : "Tilføj alias",
     "Create alias" : "Opret alias",
     "Cancel" : "Annuller",
-    "Put my text to the bottom of a reply instead of on top of it." : "Sæt min tekst til bunden af et svar i stedet for oven på den.",
+    "Search in the body of messages in priority Inbox" : "Søg i hovedteksten i beskeder i prioritets indbakke ",
+    "Activate" : "Aktivér",
+    "Mark as important" : "Markér som vigtig",
+    "Remind about messages that require a reply but received none" : "Mind mig om beskeder som kræver et svar, men ikke har modtaget et",
+    "Use internal addresses" : "Anvend interne adresser",
     "Could not update preference" : "Præference kunne ikke opdateres",
     "Mail settings" : "Mail indstillinger",
     "Accounts" : "Konti",
     "Add mail account" : "Tilføj mail konto",
+    "Settings for:" : "Indstillinger for:",
     "General" : "Generelt",
+    "Layout" : "Layout",
     "List" : "Liste",
+    "Horizontal split" : "Horisontal opdeling",
     "Sorting" : "Sortering",
+    "Newest" : "Nyeste",
+    "Oldest" : "Ældste",
+    "Show all messages in thread" : "Vis alle beskeder i tråde",
+    "Show only the selected message" : "Vis kun den valgte besked",
+    "Reply text position" : "Svartekst placering",
+    "Search in body" : "Søg i body",
+    "Gravatar settings" : "Gravatar indstillinger",
     "Use Gravatar and favicon avatars" : "Brug Gravatar og favicon avatarer",
+    "Mailto" : "Mail til",
     "Register as application for mail links" : "Registrer som program til at åbne mail links",
     "Register" : "Register",
+    "Text blocks" : "Tekstblokke",
+    "Create a new text block" : "Opret en ny tekstblok",
+    "Shared with me" : "Delt med mig",
+    "Privacy and security" : "Privatliv og sikkerhed",
+    "Data collection consent" : "Dataindsamlingssamtykke",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Tillad, at appen indsamler data om dine interaktioner. Baseret på disse data vil appen tilpasse sig dine præferencer. Dataene gemmes kun lokalt.",
     "Trusted senders" : "Betroede afsendere",
+    "Internal addresses" : "Interne adresser",
+    "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Fremhæv eksterne e-mailadresser ved at aktivere denne funktion. Håndter dine interne adresser og domæner, for at sikre at genkendte kontakter forbliver ikke markerede.",
+    "S/MIME" : "S/MIME",
     "Manage S/MIME certificates" : "Administrer S/MIME-certifikater",
+    "Mailvelope" : "Mailvelope",
+    "Mailvelope is a browser extension that enables easy OpenPGP encryption and decryption for emails." : "Mailvelope er en browser udvidelse som giver mulighed for let OpenPGP kryptering og dekryptering til e-mails.",
+    "Mailvelope is enabled for the current domain." : "Mailvelope er aktiveret for det aktuelle domæne.",
+    "Step 1: Install Mailvelope browser extension" : "Trin 1: Installer Mailvelope browser udvidelse",
+    "Step 2: Enable Mailvelope for the current domain" : "Trin 2: Aktiver Mailvelope for det aktuelle domæne",
     "About" : "Om",
     "Keyboard shortcuts" : "Tastaturgenveje",
     "Compose new message" : "Skriv en ny meddelelse",
@@ -116,9 +164,21 @@ OC.L10N.register(
     "Search" : "Søg",
     "Send" : "Send",
     "Refresh" : "Opdatér",
+    "New text block" : "Ny tekstblok",
+    "Title of the text block" : "Titel på ny tekstblok",
+    "Content of the text block" : "Indhold i tekstblok",
     "Ok" : "OK",
+    "No certificate" : "Intet certifikat",
+    "Certificate updated" : "Certifikat opdateret",
+    "Could not update certificate" : "Kunne ikke opdatere certifikat",
+    "{commonName} - Valid until {expiryDate}" : "{commonName} - Gyldig indtil {expiryDate}",
+    "Select an alias" : "Vælg et alias",
+    "Select certificates" : "Vælg certifikater",
+    "Update Certificate" : "Opdatér certifikat",
     "Encrypt with S/MIME and send later" : "Krypter med S/MIME og send senere",
     "Encrypt with S/MIME and send" : "Krypter med S/MIME og send",
+    "Encrypt with Mailvelope and send later" : "Krypter med Mailvelope og send senerend send later",
+    "Encrypt with Mailvelope and send" : "Krypter med Mailvelope og send",
     "Send later" : "Send senere",
     "Message {id} could not be found" : "Beskeden {id} kunne ikke findes",
     "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Signer eller krypter med S/MIME blev valgt, men vi har ikke et certifikat for det valgte alias. Beskeden bliver ikke underskrevet eller krypteret.",
@@ -129,6 +189,7 @@ OC.L10N.register(
     "From" : "Fra",
     "Select account" : "Vælg konto",
     "To" : "Til",
+    "Cc/Bcc" : "Cc/Bcc",
     "Select recipient" : "Vælg modtager",
     "Contact or email address …" : "Kontakt eller email…",
     "Cc" : "Cc",
@@ -148,6 +209,7 @@ OC.L10N.register(
     "Disable formatting" : "Deaktiver formatering",
     "Upload attachment" : "Upload vedhæftning",
     "Add attachment from Files" : "Vedhæft fra filer",
+    "Add share link from Files" : "Tilføj delingslink fra Filer",
     "Smart picker" : "Smart Vælger",
     "Request a read receipt" : "Anmod om en læsekvittering",
     "Sign message with S/MIME" : "Underskriv besked med S/MIME",
@@ -164,18 +226,41 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Vælg en fil, der skal tilføjes som vedhæftning",
     "Choose a file to share as a link" : "Vælg en fil der skal deles som link",
     "_{count} attachment_::_{count} attachments_" : ["{count} vedhæftet fil","{count} vedhæftede filer"],
+    "Untitled message" : "Unavngivet besked",
+    "Expand composer" : "Udvid composer",
+    "Close composer" : "Luk composer",
     "Confirm" : "Bekræft",
+    "Tag: {name} deleted" : "Tag: {name} slettet",
+    "An error occurred, unable to delete the tag." : "En fejl opstod, kunne ikke slette tagget",
+    "The tag will be deleted from all messages." : "Tagget bliver slettet fra alle beskeder.",
     "Plain text" : "Klartekst",
     "Rich text" : "Formateret tekst",
     "No messages in this folder" : "Ingen beskeder i denne mappe",
     "No messages" : "Ingen beskeder",
     "Blind copy recipients only" : "Kun blinde kopi-modtagere",
     "No subject" : "Intet emne",
+    "{markup-start}Draft:{markup-end} {subject}" : "{markup-start}Kladde:{markup-end} {subject}",
+    "Later today – {timeLocale}" : "Senere i dag – {timeLocale}",
     "Set reminder for later today" : "Sæt påmindelse for senere i dag",
+    "Tomorrow – {timeLocale}" : "I morgen – {timeLocale}",
     "Set reminder for tomorrow" : "Sæt påmindelse for i morgen",
+    "This weekend – {timeLocale}" : "Denne weekend – {timeLocale}",
     "Set reminder for this weekend" : "Sæt påmindelse for denne weekend",
+    "Next week – {timeLocale}" : "Næste uge – {timeLocale}",
     "Set reminder for next week" : "Sæt påmindelse for næste weekend",
+    "Could not apply tag, configured tag not found" : "Kunne ikke tilføje tag, konfigureret tag ikke fundet",
+    "Could not move thread, destination mailbox not found" : "Kunne ikke flytte tråd, destinationsmailboks ikke fundet",
+    "Could not execute quick action" : "Kunne ikke udføre hurtig handling",
+    "Quick action executed" : "Hurtig handlig udført",
+    "No trash folder configured" : "Ingen skraldespandsmappe konfigureret",
     "Could not delete message" : "Kunne ikke slette beskeden",
+    "Could not archive message" : "Kunne ikke arkivere besked",
+    "Thread was snoozed" : "Tråd blev snoozet",
+    "Could not snooze thread" : "Kunne ikke snooze tråd",
+    "Thread was unsnoozed" : "Snooze blev fjernet fra tråd",
+    "Could not unsnooze thread" : "Snooze kunne ikke fjernes fra tråd",
+    "This summary was AI generated" : "Dette sammendrag blev genereret af AI",
+    "Encrypted message" : "Krypteret besked",
     "This message is unread" : "Denne besked er ulæst",
     "Unfavorite" : "U-favorit",
     "Favorite" : "Favorit",
@@ -185,14 +270,23 @@ OC.L10N.register(
     "Mark not spam" : "Marker ikke spam",
     "Mark as spam" : "Marker som spam",
     "Edit tags" : "Redigér mærker",
+    "Snooze" : "Snooze",
+    "Unsnooze" : "Fjern snooze",
     "Move thread" : "Flyt tråden",
+    "Move Message" : "Flyt besked",
+    "Archive thread" : "Arkivér tråd",
+    "Archive message" : "Arkivér besked",
     "Delete thread" : "Slet tråd",
     "Delete message" : "Slet besked",
     "More actions" : "Flere handlinger",
     "Back" : "Tilbage",
+    "Set custom snooze" : "Sæt brugerdefineret snooze",
     "Edit as new message" : "Redigér som ny besked",
+    "Reply with meeting" : "Svar med møde",
     "Create task" : "Opret opgave",
     "Download message" : "Download besked",
+    "Back to all actions" : "Tilbage til alle handlinger",
+    "Manage quick actions" : "Styr hurtig handlinger",
     "Load more" : "Hent flere",
     "_Mark {number} read_::_Mark {number} read_" : ["Marker {number} læst","Marker {number} som læst"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Marker {number} som ulæst","Marker {number} som ulæst"],
@@ -201,16 +295,22 @@ OC.L10N.register(
     "_Unfavorite {number}_::_Unfavorite {number}_" : ["Fjern foretrukken {number}","Fjern foretrukken {number}"],
     "_Favorite {number}_::_Favorite {number}_" : ["Favorit {number}","Favoriser {number}"],
     "_Unselect {number}_::_Unselect {number}_" : ["Fravælg {number}","Fravælg {number}"],
+    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Marker {number} som spam","Markér {number} som spam"],
+    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["Marker {number} som ikke spam","Markér {number} som ikke spam"],
+    "_Edit tags for {number}_::_Edit tags for {number}_" : ["Rediger tags for {number}","Redigér tags for {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Flyt {number} tråd","Flyt {number} tråde"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Videresend {number} som vedhæftet fil","Videresend {number} som vedhæftet fil"],
     "Mark as unread" : "Markér som ulæst",
     "Mark as read" : "Markér som læst",
+    "Mark as unimportant" : "Markér som ikke vigtig",
     "Report this bug" : "Rapporter denne fejl",
     "Event created" : "Begivenhed oprettet",
     "Could not create event" : "Begivenheden kunne ikke oprettes",
     "Create event" : "Opret begivenhed",
     "All day" : "Hele dagen",
     "Attendees" : "Deltagere",
+    "You can only invite attendees if your account has an email address set" : "Du kan kun invitere deltagere hvis din konto har en e-mail tilknyttet",
+    "Select calendar" : "Vælg kalender",
     "Description" : "Beskrivelse",
     "Create" : "Opret",
     "This event was updated" : "Denne begivenhed blev opdateret",
@@ -218,6 +318,7 @@ OC.L10N.register(
     "{attendeeName} tentatively accepted your invitation" : "{attendeeName} accepterede foreløbigt din invitation",
     "{attendeeName} declined your invitation" : "{attendeeName} afviste din invitation",
     "{attendeeName} reacted to your invitation" : "{attendeeName} reagerede på din invitation",
+    "Failed to save your participation status" : "Kunne ikke gemme deltagerstatus",
     "You accepted this invitation" : "Du accepterede denne invitation",
     "You tentatively accepted this invitation" : "Du accepterede foreløbigt denne invitation",
     "You declined this invitation" : "Du afviste denne invitation",
@@ -231,33 +332,70 @@ OC.L10N.register(
     "Decline" : "Afvis",
     "Tentatively accept" : "Accepter foreløbigt",
     "More options" : "Flere muligheder",
+    "This message has an attached invitation but the invitation dates are in the past" : "Denne besked har en vedhæftet invitation, men invitationens datoer er i fortiden",
+    "This message has an attached invitation but the invitation does not contain a participant that matches any configured mail account address" : "Denne besked har en vedhæftet invitation, men invitationen indeholder ikke en deltager som matcher nogen konfigureret mail konto adresse",
+    "Could not remove internal address {sender}" : "Kunne ikke fjerne interne adresser {sender}",
+    "Could not add internal address {address}" : "Kunne ikke tilføje interne adresser {address}",
+    "individual" : "individuel",
+    "domain" : "domæne",
     "Remove" : "Fjern",
     "email" : "e-mail",
+    "Add internal address" : "Tilføj intern adresse",
+    "Add internal email or domain" : "Tilføj interne e-mail eller domæne",
+    "Could not mark message as seen/unseen" : "Kunne ikke markere besked som set/ikke set",
     "Last hour" : "Seneste time",
     "Today" : "I dag",
+    "Yesterday" : "I går",
     "Last week" : "Seneste uge",
+    "Last month" : "Sidste måned",
+    "Older" : "Ældre",
+    "Could not open folder" : "Kunne ikke åbne mappe",
     "Loading messages …" : "Indlæser beskeder...",
+    "Indexing your messages. This can take a bit longer for larger folders." : "Indekserer dine beskeder. Dette kan tage en smule længere for større mapper.",
     "Choose target folder" : "Vælg destinationsmappe",
     "No more submailboxes in here" : "Ikke flere underpostkasser herinde",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Beskeder vil automatisk blive markeret som vigtige baseret på, hvilke meddelelser du har interageret med eller markeret som vigtige. I begyndelsen skal du muligvis manuelt ændre vigtigheden for at lære systemet, men det vil forbedres med tiden.",
+    "Follow up" : "Opfølgning",
+    "Follow up info" : "Opfølgningsinfo",
+    "Load more follow ups" : "Indlæs flere opfølgninger",
     "Important info" : "Vigtig information",
+    "Load more important messages" : "Indlæs flere vigtige beskeder",
     "Other" : "Andet",
+    "Load more other messages" : "Indlæs flere andre beskeder",
+    "Could not send mdn" : "Kunne ikke sende mdn",
     "The sender of this message has asked to be notified when you read this message." : "Afsenderen af denne besked har bedt om at blive underrettet, når du læser denne besked.",
+    "Notify the sender" : "Underret afsenderen",
+    "Message was snoozed" : "Beskeden blev snoozet",
+    "Could not snooze message" : "Kunne ikke snooze beskeden",
+    "Message was unsnoozed" : "Snooze blev fjernet fra beskeden",
+    "Could not unsnooze message" : "Kunne ikke fjerne snooze fra beskeden",
     "Forward" : "Videresend",
     "Move message" : "Flyt besked",
     "Translate" : "Oversæt",
     "Forward message as attachment" : "Videresend besked som vedhæftet fil",
     "View source" : "Vis kildekode",
+    "Print message" : "Udskriv besked",
+    "Create mail filter" : "Opret mailfilter",
     "Unnamed" : "Unavngiven",
     "Embedded message" : "Indlejret besked",
+    "Attachment saved to Files" : "Vedhæftning gemt til Filer",
+    "Attachment could not be saved" : "Vedhæftning kunne ikke gemmes",
+    "calendar imported" : "kalender importeret",
     "Choose a folder to store the attachment in" : "Vælg den mappe, som vedhæftningen skal gemmes i",
     "Import into calendar" : "Importér til kalender",
     "Download attachment" : "Hent vedhæftning",
     "Save to Files" : "Gem til filer",
+    "Attachments saved to Files" : "Vedhæftninger gemt til Filer",
+    "Error while saving attachments" : "Fejl under lagring af vedhæftninger",
+    "View fewer attachments" : "Vis færre vedhæftninger",
     "Choose a folder to store the attachments in" : "Vælg den mappe, hvor vedhæftningerne skal gemmes i",
     "Save all to Files" : "Gem alle filer",
+    "Download Zip" : "Download zip",
+    "_View {count} more attachment_::_View {count} more attachments_" : ["Vis {count} flere vedhæftning","Vis {count} flere vedhæftningerore attachments"],
+    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Denne besked er krypteret med PGP. Installer Mailvelope for at dekryptere den.",
     "The images have been blocked to protect your privacy." : "Dette billede er blevet blokeret for at beskytte dit privatliv.",
     "Show images" : "Vis billeder",
+    "Show images temporarily" : "Vis billeder midlertidigt",
     "Always show images from {sender}" : "Altid vis billeder fra {sender}",
     "Always show images from {domain}" : "Altid vis billeder fra {domain}",
     "Quoted text" : "Citeret tekst",
@@ -265,6 +403,8 @@ OC.L10N.register(
     "Moving" : "Flytter",
     "Moving thread" : "Flytter tråd",
     "Moving message" : "Flytter besked",
+    "Used quota: {quota}% ({limit})" : "Anvendt kvote: {quota}% ({limit})",
+    "Used quota: {quota}%" : "Anvendt kvote: {quota}%",
     "Remove account" : "Fjern konto",
     "Remove {email}" : "Fjern {email}",
     "Add folder" : "Tilføj mappe",
@@ -275,22 +415,37 @@ OC.L10N.register(
     "Show all folders" : "Vis alle mapper",
     "Collapse folders" : "Fold mapper sammen",
     "_{total} message_::_{total} messages_" : ["{total} besked","{total} beskeder"],
+    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} ulæst ud af {total}","{unread} ulæst ud af {total}"],
     "Loading …" : "Indlæser…",
+    "All messages in mailbox will be deleted." : "Alle beskeder i din mailboks bliver slettet.",
     "Clear mailbox {name}" : "Ryd postkasse {name}",
+    "Clear folder" : "Ryd mappe",
+    "The folder and all messages in it will be deleted." : "Mappen og alle beskeder i den vil blive slettet.",
     "Delete folder" : "Slet mappe",
+    "Delete folder {name}" : "Slet mappe {name}",
+    "An error occurred, unable to rename the mailbox." : "En fejl er opstået, kunne ikke omdøbe mailboksen.",
+    "Please wait 10 minutes before repairing again" : "Vent venligst 10 minutter inden du reparerer igen",
     "Mark all as read" : "Markér alle som læst",
     "Mark all messages of this folder as read" : "Markér alle beskeder i denne mappe som læst",
     "Add subfolder" : "Tilføj undermappe",
     "Rename" : "Omdøb",
     "Move folder" : "Flyt mappe",
+    "Repair folder" : "Reparér mappe",
     "Clear cache" : "Ryd cache",
+    "Clear locally cached data, in case there are issues with synchronization." : "Ryd lokalt cachet data, hvis der er problemer med synkronisering.",
     "Subscribed" : "Abonneret",
     "Sync in background" : "Synkroniser i baggrunden",
     "Outbox" : "Udbakke",
+    "Translate this message to {language}" : "Oversæt denne besked til {language}",
     "New message" : "Ny besked",
     "Edit message" : "Rediger besked",
     "Draft" : "Kladde",
     "Reply" : "Besvar",
+    "Message saved" : "Besked gemt",
+    "Failed to save message" : "Kunne ikke gemme besked",
+    "Failed to save draft" : "Kunne ikke gemme kladde",
+    "attachment" : "vedhæftning",
+    "attached" : "vedhæftet",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Du prøver at sende til mange modtagere i Til og/eller Cc. Overvej at bruge Bcc til at skjule modtageradresser.",
     "Error sending your message" : "Fejl ved afsendelse af din besked",
     "Retry" : "Prøv igen",
@@ -298,26 +453,55 @@ OC.L10N.register(
     "Send anyway" : "Send alligevel",
     "Welcome to {productName} Mail" : "Velkommen til {productName} mail",
     "Start writing a message by clicking below or select an existing message to display its contents" : "Begynd at skrive en besked ved at klikke nedenfor eller vælg en eksisterende besked for at få vist dens indhold",
+    "Edit absence settings" : "Redigér fraværsindstillinger",
     "First day" : "Første dag",
+    "Last day (optional)" : "Sidste dag (valgfri)",
+    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} vil blive erstattet med emnet for beskeden som du svarer på",
     "Message" : "Besked",
     "Could not open outbox" : "Kunne ikke åbne udbakken",
+    "Could not copy to \"Sent\" folder" : "Kunne ikke kopiere til mappen \"Sendt\" folder",
+    "Mail server error" : "Mailserver fejl",
+    "Message could not be sent" : "Beskeden kunne ikke sendes",
+    "Message deleted" : "Besked slettet",
+    "Copy to \"Sent\" Folder" : "Kopiér til mappen \"Sendt\"",
+    "Copy to Sent Folder" : "Kopiér til mappen Sendt",
+    "Hide suspicious links" : "Gem mistænkelige links",
+    "Show suspicious links" : "Vis mistænkelige links",
+    "link text" : "linktekst",
+    "Copied email address to clipboard" : "Kopierede e-mail adresse til udklipsholder",
+    "Could not copy email address to clipboard" : "Kunne ikke kopiere e-mail adresse til udklipsholder",
+    "Contacts with this address" : "Kontakter med denne adresse",
+    "Add to Contact" : "Tilføj til kontakt",
     "New Contact" : "Ny kontakt",
     "Copy to clipboard" : "Kopier til udklipsholder",
+    "Contact name …" : "Kontaktnavn ...",
     "Add" : "Tilføj",
     "Show less" : "Vis mindre",
+    "Show more" : "Vis mere",
     "Clear" : "Ryd",
+    "Search in folder" : "Søg i mappe",
+    "Open search modal" : "Åbn søgemodal",
     "Close" : "Luk",
     "Search parameters" : "Søgeparametre",
+    "Search subject" : "Søg emne",
     "Body" : "Krop",
+    "Search body" : "Søg hovedtekst",
     "Date" : "Dato",
     "Pick a start date" : "Vælg en startdato",
     "Pick an end date" : "Vælg en slutdato",
+    "Select senders" : "Vælg afsendere",
+    "Select recipients" : "Vælg modtagere",
+    "Select CC recipients" : "Vælg CC modtagere",
+    "Select BCC recipients" : "Vælg BCC modtagere",
     "Tags" : "Tags",
     "Select tags" : "Vælg tags",
     "Marked as" : "Markeret som",
     "Has attachments" : "Har vedhæftede filer",
     "Mentions me" : "Omtalte mig",
+    "Has attachment" : "Har vedhæftning",
     "Last 7 days" : "Sidste 7 dage",
+    "From me" : "Fra mig",
+    "Enable mail body search" : "Aktivér søgning i mailhovedtekst",
     "Sieve credentials" : "Sieve legitimationsoplysninger",
     "IMAP credentials" : "IMAP legitimationsoplysninger",
     "Custom" : "Brugerdefineret",
@@ -327,12 +511,20 @@ OC.L10N.register(
     "Saving new tag name …" : "Gemmer nyt tag navn ...",
     "Tag already exists" : "Mærket eksisterer allerede",
     "Add tag" : "Tilføj tag",
+    "Print" : "Udskriv",
+    "Could not print message" : "Kunne ikke udskrive besked",
     "Loading thread" : "Indlæser tråd",
     "Not found" : "Ikke fundet",
+    "Encrypted & verified " : "Krypteret & verificeret",
+    "Signature verified" : "Signatur verificeret",
+    "Signature unverified " : "Signatur ikke verificeret",
     "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Denne meddelelse indeholder en verificeret digital S/MIME signatur. Meddelelsen er ikke blevet ændret, siden den blev sendt.",
     "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Denne meddelelse indeholder en ubekræftet digital S/MIME signatur. Meddelelsen kan være blevet ændret, siden den blev sendt, eller der er ikke tillid til underskriverens certifikat.",
     "Reply all" : "Besvar alle",
+    "Disable reminder" : "Deaktivér påmindelse",
     "Reply to sender only" : "Besvar kun afsender",
+    "Go to latest message" : "Gå til seneste besked",
+    "Newest message" : "Nyeste besked",
     "Translate from" : "Oversæt fra",
     "Translate to" : "Oversæt til",
     "Copy translated text" : "Kopiér oversat tekst",
@@ -352,6 +544,7 @@ OC.L10N.register(
     "Priority" : "Prioritet",
     "delete" : "Slet",
     "Edit" : "Redigér",
+    "Message View Mode" : "Besked visningstilstand",
     "Reset" : "Nulstil",
     "Client ID" : "Klient ID",
     "Client secret" : "Klienthemmelighed",
@@ -410,6 +603,8 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klik her hvis du ikke automatisk bliver videre sendt i løbet af et par sekunder.",
     "Redirect" : "Omdiriger",
     "The link leads to %s" : "Linket fører til %s",
-    "Continue to %s" : "Videre til %s"
+    "Continue to %s" : "Videre til %s",
+    "Put my text to the bottom of a reply instead of on top of it." : "Sæt min tekst til bunden af et svar i stedet for oven på den.",
+    "Vertical split" : "Vertikal opdeling"
 },
 "nplurals=2; plural=(n != 1);");
