@@ -159,7 +159,9 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Trajno de {depStation} al {arrStation}",
     "Train" : "Trajno",
     "Recipient" : "Ricevonto",
+    "Help" : "Helpo",
     "matches" : "kongruas kun",
+    "Actions" : "Agoj",
     "Priority" : "Prioritato",
     "delete" : "forigi",
     "Edit" : "Modifi",
