@@ -221,7 +221,9 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} מ־{depStation} אל {arrStation}",
     "Train from {depStation} to {arrStation}" : "רכבת מ־{depStation} אל {arrStation}",
     "Train" : "רכבת",
+    "Help" : "עזרה",
     "matches" : "תואם",
+    "Actions" : "פעולות",
     "Priority" : "עדיפות",
     "Tag" : "תגית",
     "delete" : "מחיקה",
