@@ -106,7 +106,9 @@ OC.L10N.register(
     "Custom" : "ინდივიდუალური",
     "Add tag" : "ტეგის დამატება",
     "Recipient" : "მიმღები",
+    "Help" : "დახმარება",
     "matches" : "ემთხვევა",
+    "Actions" : "მოქმედებები",
     "Priority" : "პრიორიტეტი",
     "delete" : "წაშლა",
     "Edit" : "შეცვლა",
