@@ -124,6 +124,7 @@ class MessagesController extends Controller {
 	 * @param int $cursor
 	 * @param string $filter
 	 * @param int|null $limit
+	 * @param string $view returns messages in requested view ('singleton' or 'threaded')
 	 * @param string|null $v Cache buster version to guarantee unique urls (will trigger HTTP caching if set)
 	 *
 	 * @return JSONResponse
@@ -136,6 +137,7 @@ class MessagesController extends Controller {
 		?int $cursor = null,
 		?string $filter = null,
 		?int $limit = null,
+		?string $view = null,
 		?string $v = null): JSONResponse {
 		try {
 			$mailbox = $this->mailManager->getMailbox($this->currentUserId, $mailboxId);
@@ -145,15 +147,19 @@ class MessagesController extends Controller {
 		}
 
 		$this->logger->debug("loading messages of mailbox <$mailboxId>");
+		$sort = $this->preferences->getPreference($this->currentUserId, 'sort-order', 'newest') === 'newest' ? IMailSearch::ORDER_NEWEST_FIRST : IMailSearch::ORDER_OLDEST_FIRST;
+
+		$view = $view === 'singleton' ? IMailSearch::VIEW_SINGLETON : IMailSearch::VIEW_THREADED;
 
-		$order = $this->preferences->getPreference($this->currentUserId, 'sort-order', 'newest') === 'newest' ? 'DESC': 'ASC';
 		$messages = $this->mailSearch->findMessages(
 			$account,
 			$mailbox,
-			$order,
+			$sort,
 			$filter === '' ? null : $filter,
 			$cursor,
-			$limit
+			$limit,
+			$this->currentUserId,
+			$view
 		);
 
 		$response = new JSONResponse($messages);
@@ -582,9 +588,9 @@ class MessagesController extends Controller {
 				$client->logout();
 			}
 
-			$htmlResponse = $plain ?
-				HtmlResponse::plain($html) :
-				HtmlResponse::withResizer(
+			$htmlResponse = $plain
+				? HtmlResponse::plain($html)
+				: HtmlResponse::withResizer(
 					$html,
 					$this->nonceManager->getNonce(),
 					$this->urlGenerator->getAbsoluteURL(
@@ -906,6 +912,50 @@ class MessagesController extends Controller {
 
 	}
 
+	/**
+	 * @NoAdminRequired
+	 *
+	 * @param int $messageId
+	 *
+	 * @return JSONResponse
+	 */
+	#[TrapError]
+	public function needsTranslation(int $messageId): JSONResponse {
+		if ($this->currentUserId === null) {
+			return new JSONResponse([], Http::STATUS_FORBIDDEN);
+		}
+		try {
+			$message = $this->mailManager->getMessage($this->currentUserId, $messageId);
+			$mailbox = $this->mailManager->getMailbox($this->currentUserId, $message->getMailboxId());
+			$account = $this->accountService->find($this->currentUserId, $mailbox->getAccountId());
+		} catch (DoesNotExistException $e) {
+			return new JSONResponse([], Http::STATUS_FORBIDDEN);
+		}
+
+		if (!$this->aiIntegrationService->isLlmProcessingEnabled()) {
+			$response = new JSONResponse([], Http::STATUS_NOT_IMPLEMENTED);
+			$response->cacheFor(60 * 60 * 24, false, true);
+			return $response;
+		}
+
+		try {
+			$requiresTranslation = $this->aiIntegrationService->requiresTranslation(
+				$account,
+				$mailbox,
+				$message,
+				$this->currentUserId
+			);
+			$response = new JSONResponse(['requiresTranslation' => $requiresTranslation === true]);
+			$response->cacheFor(60 * 60 * 24, false, true);
+			return $response;
+		} catch (ServiceException $e) {
+			$this->logger->error('Translation check failed: ' . $e->getMessage(), [
+				'exception' => $e,
+			]);
+			return new JSONResponse([], Http::STATUS_NO_CONTENT);
+		}
+	}
+
 	/**
 	 * @param int $id
 	 * @param array $attachment
