@@ -16,6 +16,7 @@ use OCA\Mail\Contracts\IMailSearch;
 use OCA\Mail\IMAP\Threading\DatabaseMessage;
 use OCA\Mail\Service\Search\Flag;
 use OCA\Mail\Service\Search\FlagExpression;
+use OCA\Mail\Service\Search\GlobalSearchQuery;
 use OCA\Mail\Service\Search\SearchQuery;
 use OCA\Mail\Support\PerformanceLogger;
 use OCA\Mail\Support\PerformanceLoggerTask;
@@ -808,20 +809,22 @@ class MessageMapper extends QBMapper {
 			$select = $qb->select(['m.id', 'm.sent_at']);
 		}
 
-		$selfJoin = $select->expr()->andX(
-			$select->expr()->eq('m.mailbox_id', 'm2.mailbox_id', IQueryBuilder::PARAM_INT),
-			$select->expr()->eq('m.thread_root_id', 'm2.thread_root_id', IQueryBuilder::PARAM_INT),
-			$select->expr()->orX(
-				$select->expr()->lt('m.sent_at', 'm2.sent_at', IQueryBuilder::PARAM_INT),
-				$select->expr()->andX(
-					$select->expr()->eq('m.sent_at', 'm2.sent_at', IQueryBuilder::PARAM_INT),
-					$select->expr()->lt('m.message_id', 'm2.message_id', IQueryBuilder::PARAM_STR),
-				),
-			),
-		);
+		$select->from($this->getTableName(), 'm');
 
-		$select->from($this->getTableName(), 'm')
-			->leftJoin('m', $this->getTableName(), 'm2', $selfJoin);
+		if ($query->getThreaded()) {
+			$selfJoin = $select->expr()->andX(
+				$select->expr()->eq('m.mailbox_id', 'm2.mailbox_id', IQueryBuilder::PARAM_INT),
+				$select->expr()->eq('m.thread_root_id', 'm2.thread_root_id', IQueryBuilder::PARAM_INT),
+				$select->expr()->orX(
+					$select->expr()->lt('m.sent_at', 'm2.sent_at', IQueryBuilder::PARAM_INT),
+					$select->expr()->andX(
+						$select->expr()->eq('m.sent_at', 'm2.sent_at', IQueryBuilder::PARAM_INT),
+						$select->expr()->lt('m.message_id', 'm2.message_id', IQueryBuilder::PARAM_STR),
+					),
+				),
+			);
+			$select->leftJoin('m', $this->getTableName(), 'm2', $selfJoin);
+		}
 
 		if (!empty($query->getFrom())) {
 			$select->innerJoin('m', 'mail_recipients', 'r0', 'm.id = r0.message_id');
@@ -1007,7 +1010,9 @@ class MessageMapper extends QBMapper {
 			);
 		}
 
-		$select->andWhere($qb->expr()->isNull('m2.id'));
+		if ($query->getThreaded()) {
+			$select->andWhere($qb->expr()->isNull('m2.id'));
+		}
 
 		if ($sortOrder === 'ASC') {
 			$select->orderBy('m.sent_at', $sortOrder);
@@ -1076,6 +1081,16 @@ class MessageMapper extends QBMapper {
 			->from('mail_mailboxes', 'mb')
 			->join('mb', 'mail_accounts', 'a', $qb->expr()->eq('a.id', 'mb.account_id', IQueryBuilder::PARAM_INT))
 			->where($qb->expr()->eq('a.user_id', $qb->createNamedParameter($user->getUID())));
+
+		if ($query instanceof GlobalSearchQuery) {
+			$excludeMailboxIds = $query->getExcludeMailboxIds();
+			if (count($excludeMailboxIds) > 0) {
+				$selectMailboxIds->andWhere(
+					$qb->expr()->notIn('mb.id', $qb->createNamedParameter($excludeMailboxIds, IQueryBuilder::PARAM_INT_ARRAY))
+				);
+			}
+		}
+
 		$select->where(
 			$qb->expr()->in('m.mailbox_id', $qb->createFunction($selectMailboxIds->getSQL()), IQueryBuilder::PARAM_INT_ARRAY)
 		);
@@ -1396,9 +1411,9 @@ class MessageMapper extends QBMapper {
 		$subSelect = $this->db->getQueryBuilder();
 
 		$subSelect
-			->select($sortOrder === IMailSearch::ORDER_NEWEST_FIRST ?
-				$subSelect->func()->min('sent_at') :
-				$subSelect->func()->max('sent_at'))
+			->select($sortOrder === IMailSearch::ORDER_NEWEST_FIRST
+				? $subSelect->func()->min('sent_at')
+				: $subSelect->func()->max('sent_at'))
 			->from($this->getTableName())
 			->where(
 				$subSelect->expr()->eq('mailbox_id', $select->createNamedParameter($mailbox->getId(), IQueryBuilder::PARAM_INT)),
@@ -1411,9 +1426,9 @@ class MessageMapper extends QBMapper {
 			$select->expr()->eq('m.mailbox_id', 'm2.mailbox_id', IQueryBuilder::PARAM_INT),
 			$select->expr()->eq('m.thread_root_id', 'm2.thread_root_id', IQueryBuilder::PARAM_INT),
 			$select->expr()->orX(
-				$sortOrder === IMailSearch::ORDER_NEWEST_FIRST ?
-					$select->expr()->lt('m.sent_at', 'm2.sent_at', IQueryBuilder::PARAM_INT) :
-					$select->expr()->gt('m.sent_at', 'm2.sent_at', IQueryBuilder::PARAM_INT),
+				$sortOrder === IMailSearch::ORDER_NEWEST_FIRST
+					? $select->expr()->lt('m.sent_at', 'm2.sent_at', IQueryBuilder::PARAM_INT)
+					: $select->expr()->gt('m.sent_at', 'm2.sent_at', IQueryBuilder::PARAM_INT),
 				$select->expr()->andX(
 					$select->expr()->eq('m.sent_at', 'm2.sent_at', IQueryBuilder::PARAM_INT),
 					$select->expr()->lt('m.message_id', 'm2.message_id', IQueryBuilder::PARAM_STR),
