@@ -62,6 +62,7 @@ class AdminSettings implements ISettings {
 		$this->classificationSettingsService = $classificationSettingsService;
 	}
 
+	#[\Override]
 	public function getForm() {
 		$this->initialStateService->provideInitialState(
 			Application::APP_ID,
@@ -84,6 +85,12 @@ class AdminSettings implements ISettings {
 			$this->config->getAppValue('mail', 'allow_new_mail_accounts', 'yes') === 'yes'
 		);
 
+		$this->initialStateService->provideInitialState(
+			Application::APP_ID,
+			'layout_message_view',
+			$this->config->getAppValue('mail', 'layout_message_view', 'threaded')
+		);
+
 		$this->initialStateService->provideInitialState(
 			Application::APP_ID,
 			'llm_processing',
@@ -150,10 +157,12 @@ class AdminSettings implements ISettings {
 		return new TemplateResponse(Application::APP_ID, 'settings-admin');
 	}
 
+	#[\Override]
 	public function getSection() {
 		return 'groupware';
 	}
 
+	#[\Override]
 	public function getPriority() {
 		return 90;
 	}
